<?php
namespace Teknisa\FIN\Factories;

/**
 * Class ImportacaoBancariaFactory
 * @package Teknisa\FIN\Factories
 */
class ImportacaoBancariaFactory {

    protected $connection;
    protected $entityManager;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    /*
     * Busca Faixas de Controle
     */
    public function getCtrltrckidacs($dstrackingid) {
        
        /** @var $params */
        $params = array();
        $params['DSTRACKINGID'] = $dstrackingid;
        
        $sql = "SELECT NRCTRLTRCKIDACS, DSTRACKINGID, DSTPDOCUMENTO, DSNMEMPRESAORIG, NMARQUIVORET, 
                       IDRETIRADO, DTRETIRADA, DTDISPONIVEL, NRORG, IDATIVO, DTINCLUSAO, DTULTATU, 
                       NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDSTATIMPORT, 
                       IDTPARQUIVO, CDEMPRESA, CDFILIAL, CDOPERADOR
                  FROM CTRLTRCKIDACS
                 WHERE DSTRACKINGID    = :DSTRACKINGID";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    /*
     * Busca Conteúdo Faixa de Controle
     */
    public function getConttrckidacs($nrctrltrckidacs, $dstrackingid) {
        
        /** @var $params */
        $params = array();
        $params['NRCTRLTRCKIDACS'] = $nrctrltrckidacs;
        $params['DSTRACKINGID']    = $dstrackingid;
        
        $sql = "SELECT NRCTRLTRCKIDACS, DSTRACKINGID, DSCONTTRCKIDACS, NRORG, IDATIVO, DTINCLUSAO,
                       DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU
                  FROM CONTTRCKIDACS
                 WHERE NRCTRLTRCKIDACS = :NRCTRLTRCKIDACS
                   AND DSTRACKINGID    = :DSTRACKINGID";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }
    
    /*
     * Busca Conteúdo Faixa de Controle por Status de Importação
     */
    public function getConttrckidacsByIdstatimport($idstatimport) {
        
        /** @var $params */
        $params = array();
        $params['IDSTATIMPORT'] = $idstatimport;
        
        $sql = "SELECT CT.NRCTRLTRCKIDACS, CT.DSTRACKINGID, CT.IDSTATIMPORT, CT.IDTPARQUIVO, CO.DSCONTTRCKIDACS
                  FROM CTRLTRCKIDACS CT, CONTTRCKIDACS CO
                 WHERE CT.NRCTRLTRCKIDACS = CO.NRCTRLTRCKIDACS
                   AND CT.DSTRACKINGID    = CO.DSTRACKINGID
                   AND CT.IDSTATIMPORT    = :IDSTATIMPORT
                   AND CT.IDTPARQUIVO     <> 'E'";
        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetchAll();
    }
    
    /*
     * Busca Parametrização Faixa de Controle
     */
    public function getParamTrckIdAcs(){
        
        /** @var $params */
        $params = array();
        
        $sql = "SELECT * FROM PARAMTRCKIDACS";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }
    
    /*
     * Insere Faixa de Controle
     */
    public function insertCtrltrckidacs(
        $nrctrltrckidacs, $dstrackingid, $dstpdocumento, $dsnmempresaorig, 
        $dtdisponivel, $idtparquivo, $nrorg, $cdempresa, $cdfilial, $cdoperador
    ){
        
        /** @var $params */
        $params = array();
        $params['NRCTRLTRCKIDACS'] = $nrctrltrckidacs;
        $params['DSTRACKINGID'  ]  = $dstrackingid;
        $params['DSTPDOCUMENTO']   = $dstpdocumento;
        $params['DSNMEMPRESAORIG'] = $dsnmempresaorig;
        $params['DTDISPONIVEL']    = $dtdisponivel;
        $params['IDTPARQUIVO']     = $idtparquivo;
        $params['NRORG']           = $nrorg;
        $params['CDEMPRESA']       = $cdempresa;
        $params['CDFILIAL']        = $cdfilial;
        $params['CDOPERADOR']      = $cdoperador;
        
        $sql = "INSERT INTO CTRLTRCKIDACS (
                    NRCTRLTRCKIDACS, DSTRACKINGID, DSTPDOCUMENTO, DSNMEMPRESAORIG, DTDISPONIVEL, IDTPARQUIVO,
                    DTULTATU, DTINCLUSAO, NRORG, NRORGINCLUSAO, NRORGULTATU, IDATIVO, CDEMPRESA,
                    CDFILIAL, CDOPERADOR
                ) VALUES (
                    :NRCTRLTRCKIDACS, :DSTRACKINGID, :DSTPDOCUMENTO, :DSNMEMPRESAORIG,
                    TO_DATE(:DTDISPONIVEL, 'DD/MM/YYYY HH24:MI:SS'), :IDTPARQUIVO, SYSDATE, SYSDATE,
                    :NRORG, :NRORG, :NRORG, 'S', :CDEMPRESA, :CDFILIAL, :CDOPERADOR
                )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /*
     * Insere Conteúdo Faixa de Controle
     */
    public function insertConttrckidacs(
        $nrctrltrckidacs, $dstrackingid, $dsconttrckidacs, $nrorg
    ){
        
        /** @var $params */
        $params = array();
        $params['NRCTRLTRCKIDACS'] = $nrctrltrckidacs;
        $params['DSTRACKINGID'  ]  = $dstrackingid;
        $params['DSCONTTRCKIDACS'] = $dsconttrckidacs;
        $params['NRORG']           = $nrorg;
        
        $sql = "INSERT INTO CONTTRCKIDACS (
                    NRCTRLTRCKIDACS, DSTRACKINGID, DSCONTTRCKIDACS, DTULTATU, DTINCLUSAO, NRORG,
                    NRORGINCLUSAO, NRORGULTATU, IDATIVO
                ) VALUES (
                    :NRCTRLTRCKIDACS, :DSTRACKINGID, :DSCONTTRCKIDACS, SYSDATE, SYSDATE, :NRORG,
                    :NRORG, :NRORG, 'S'
                )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /*
     * Atualiza Tipo de Arquivo Conteúdo Faixa de Controle
     */
    public function updateIdstatimportCtrltrckidacs(
        $nrctrltrckidacs, $dstrackingid, $idstatimport
    ){
        
        /** @var $params */
        $params = array();
        $params['NRCTRLTRCKIDACS'] = $nrctrltrckidacs;
        $params['DSTRACKINGID'  ]  = $dstrackingid;
        $params['IDSTATIMPORT']    = $idstatimport;
        
        $sql = "UPDATE CTRLTRCKIDACS
                   SET IDSTATIMPORT    = :IDSTATIMPORT
                 WHERE DSTRACKINGID    = :DSTRACKINGID
                   AND NRCTRLTRCKIDACS = :NRCTRLTRCKIDACS";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
}